@@ -1,6 +1,7 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
-Main interface for mq service client paginators.
+Type annotations for mq service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mq/paginators.html)
 
 Usage::
 
@@ -28,12 +29,13 @@ __all__ = ("ListBrokersPaginator",)
 
 class ListBrokersPaginator(Boto3Paginator):
     """
-    [Paginator.ListBrokers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.18/reference/services/mq.html#MQ.Paginator.ListBrokers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/mq.html#MQ.Paginator.ListBrokers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mq/paginators.html#listbrokerspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListBrokersResponseTypeDef]:
         """
-        [ListBrokers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.18/reference/services/mq.html#MQ.Paginator.ListBrokers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/mq.html#MQ.Paginator.ListBrokers.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mq/paginators.html#listbrokerspaginator)
         """
